@@ -5,7 +5,7 @@ This file is part of minos framework.
 
 Minos framework can not be copied and/or distributed without the express permission of Clariteia SL.
 """
-__version__ = "0.0.8"
+__version__ = "0.0.10"
 
 from .brokers import (
     Broker,
@@ -16,6 +16,20 @@ from .brokers import (
     Producer,
     ProducerService,
 )
+from .decorators import (
+    BrokerCommandEnrouteDecorator,
+    BrokerEnrouteDecorator,
+    BrokerEventEnrouteDecorator,
+    BrokerQueryEnrouteDecorator,
+    EnrouteAnalyzer,
+    EnrouteBuilder,
+    EnrouteDecorator,
+    EnrouteDecoratorKind,
+    RestCommandEnrouteDecorator,
+    RestEnrouteDecorator,
+    RestQueryEnrouteDecorator,
+    enroute,
+)
 from .discovery import (
     DiscoveryConnector,
     MinosDiscoveryClient,
@@ -23,7 +37,11 @@ from .discovery import (
 from .exceptions import (
     MinosActionNotFoundException,
     MinosDiscoveryConnectorException,
+    MinosHandlerException,
+    MinosHandlerNotFoundEnoughEntriesException,
+    MinosMultipleEnrouteDecoratorKindsException,
     MinosNetworkException,
+    MinosRedefinedEnrouteDecoratorException,
 )
 from .handlers import (
     CommandConsumer,
@@ -34,25 +52,39 @@ from .handlers import (
     CommandReplyConsumerService,
     CommandReplyHandler,
     CommandReplyHandlerService,
-    CommandRequest,
-    CommandResponse,
-    CommandResponseException,
     Consumer,
+    DynamicHandler,
+    DynamicReplyHandler,
     EventConsumer,
     EventConsumerService,
     EventHandler,
     EventHandlerService,
     Handler,
     HandlerEntry,
+    HandlerRequest,
+    HandlerResponse,
+    HandlerResponseException,
     HandlerSetup,
+    ReplyHandlerPool,
+)
+from .messages import (
+    Request,
+    Response,
+    ResponseException,
+    WrappedRequest,
 )
 from .rest import (
-    HttpRequest,
-    HttpResponse,
-    HttpResponseException,
     RestBuilder,
+    RestRequest,
+    RestResponse,
+    RestResponseException,
     RestService,
 )
 from .snapshots import (
     SnapshotService,
 )
+from .utils import (
+    get_host_ip,
+    get_host_name,
+    get_ip,
+)
