@@ -11,13 +11,12 @@ from __future__ import (
 
 import logging
 from typing import (
-    Optional,
+    Any,
 )
 
 from minos.common import (
     Command,
     MinosConfig,
-    MinosModel,
 )
 
 from .abc import (
@@ -32,37 +31,20 @@ class CommandBroker(Broker):
 
     ACTION = "command"
 
-    def __init__(self, *args, saga_uuid: Optional[str] = None, reply_topic: Optional[str] = None, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.reply_topic = reply_topic
-        self.saga_uuid = saga_uuid
-
     @classmethod
     def _from_config(cls, *args, config: MinosConfig, **kwargs) -> CommandBroker:
         return cls(*args, **config.commands.queue._asdict(), **kwargs)
 
-    async def send(
-        self,
-        items: list[MinosModel],
-        topic: Optional[str] = None,
-        saga_uuid: Optional[str] = None,
-        reply_topic: Optional[str] = None,
-        **kwargs,
-    ) -> int:
-        """Send a list of ``Aggregate`` instances.
+    # noinspection PyMethodOverriding
+    async def send(self, data: Any, topic: str, saga: str, reply_topic: str, **kwargs) -> int:
+        """Send a ``Command``.
 
-        :param items: A list of aggregates.
+        :param data: The data to be send.
         :param topic: Topic in which the message will be published.
-        :param saga_uuid: Saga identifier.
+        :param saga: Saga identifier.
         :param reply_topic: Topic name in which the reply will be published.
         :return: This method does not return anything.
         """
-        if topic is None:
-            topic = self.topic
-        if saga_uuid is None:
-            saga_uuid = self.saga_uuid
-        if reply_topic is None:
-            reply_topic = self.reply_topic
-        command = Command(topic, items, saga_uuid, reply_topic)
+        command = Command(topic, data, saga, reply_topic)
         logger.info(f"Sending '{command!s}'...")
         return await self.send_bytes(command.topic, command.avro_bytes)
