@@ -44,7 +44,7 @@ class Consumer(HandlerSetup):
 
     __slots__ = "_topics", "_broker", "__consumer"
 
-    def __init__(self, topics: list[str], broker: Optional[BROKER] = None, consumer: Optional[Any] = None, **kwargs):
+    def __init__(self, topics: set[str], broker: Optional[BROKER] = None, consumer: Optional[Any] = None, **kwargs):
         super().__init__(**kwargs)
         self._topics = topics
         self._broker = broker
@@ -54,6 +54,14 @@ class Consumer(HandlerSetup):
         await super()._setup()
         await self._consumer.start()
 
+    @property
+    def topics(self) -> set[str]:
+        """Topics getter.
+
+        :return: A list of string values.
+        """
+        return self._topics
+
     @property
     def _consumer(self) -> AIOKafkaConsumer:
         if self.__consumer is None:  # pragma: no cover
