@@ -24,5 +24,5 @@ class CommandReplyConsumer(Consumer):
 
     @classmethod
     def _from_config(cls, *args, config: MinosConfig, **kwargs) -> CommandReplyConsumer:
-        topics = [f"{item.name}Reply" for item in config.saga.items]
+        topics = {f"{config.service.name}QueryReply"} | {f"{item.name}Reply" for item in config.saga.items}
         return cls(topics=topics, broker=config.saga.broker, **config.saga.queue._asdict(), **kwargs)
