@@ -12,11 +12,15 @@ import logging
 from inspect import (
     isawaitable,
 )
+from itertools import (
+    chain,
+)
 from typing import (
     Any,
     Awaitable,
     Callable,
     NoReturn,
+    Optional,
     Tuple,
     Union,
 )
@@ -31,18 +35,23 @@ from minos.common import (
     MinosBroker,
     MinosConfig,
     MinosException,
-    Model,
-    ResponseException,
 )
 
+from ...decorators import (
+    EnrouteBuilder,
+)
+from ...messages import (
+    Response,
+    ResponseException,
+)
 from ..abc import (
     Handler,
 )
 from ..entries import (
     HandlerEntry,
 )
-from .messages import (
-    CommandRequest,
+from ..messages import (
+    HandlerRequest,
 )
 
 logger = logging.getLogger(__name__)
@@ -64,7 +73,13 @@ class CommandHandler(Handler):
 
     @classmethod
     def _from_config(cls, *args, config: MinosConfig, **kwargs) -> CommandHandler:
-        handlers = {item.name: {"controller": item.controller, "action": item.action} for item in config.commands.items}
+        command_decorators = EnrouteBuilder(config.commands.service).get_broker_command_query()
+        query_decorators = EnrouteBuilder(config.queries.service).get_broker_command_query()
+
+        handlers = {
+            decorator.topic: fn for decorator, fn in chain(command_decorators.items(), query_decorators.items())
+        }
+
         return cls(handlers=handlers, **config.commands.queue._asdict(), **kwargs)
 
     async def dispatch_one(self, entry: HandlerEntry) -> NoReturn:
@@ -79,33 +94,35 @@ class CommandHandler(Handler):
         fn = self.get_callback(entry.callback)
         items, status = await fn(command)
 
-        await self.broker.send(items, topic=command.reply_topic, saga_uuid=command.saga_uuid, status=status)
+        await self.broker.send(items, topic=command.reply_topic, saga=command.saga, status=status)
 
     @staticmethod
     def get_callback(
-        fn: Callable[[CommandRequest], Union[CommandRequest, Awaitable[CommandRequest]]]
-    ) -> Callable[[Command], Awaitable[Tuple[list[Model], CommandStatus]]]:
+        fn: Callable[[HandlerRequest], Union[Optional[HandlerRequest], Awaitable[Optional[HandlerRequest]]]]
+    ) -> Callable[[Command], Awaitable[Tuple[Any, CommandStatus]]]:
         """Get the handler function to be used by the Command Handler.
 
         :param fn: The action function.
         :return: A wrapper function around the given one that is compatible with the Command Handler API.
         """
 
-        async def _fn(command: Command) -> Tuple[list[Model], CommandStatus]:
+        async def _fn(command: Command) -> Tuple[Any, CommandStatus]:
             try:
-                request = CommandRequest(command)
+                request = HandlerRequest(command)
                 response = fn(request)
                 if isawaitable(response):
                     response = await response
-                return await response.content(), CommandStatus.SUCCESS
+                if isinstance(response, Response):
+                    response = await response.content()
+                return response, CommandStatus.SUCCESS
             except ResponseException as exc:
                 logger.info(f"Raised a user exception: {exc!s}")
-                return [], CommandStatus.ERROR
+                return None, CommandStatus.ERROR
             except MinosException as exc:
                 logger.warning(f"Raised a 'minos' exception: {exc!r}")
-                return [], CommandStatus.SYSTEM_ERROR
+                return None, CommandStatus.SYSTEM_ERROR
             except Exception as exc:
                 logger.exception(f"Raised an exception: {exc!r}.")
-                return [], CommandStatus.SYSTEM_ERROR
+                return None, CommandStatus.SYSTEM_ERROR
 
         return _fn
