@@ -14,12 +14,15 @@ from functools import (
 )
 from inspect import (
     isawaitable,
-    isclass,
+)
+from itertools import (
+    chain,
 )
 from typing import (
     Awaitable,
     Callable,
     NoReturn,
+    Optional,
     Union,
 )
 
@@ -28,18 +31,22 @@ from aiohttp import (
 )
 
 from minos.common import (
-    ENDPOINT,
     MinosConfig,
     MinosException,
     MinosSetup,
-    ResponseException,
     classname,
-    import_module,
 )
 
+from ..decorators import (
+    EnrouteBuilder,
+)
+from ..messages import (
+    Response,
+    ResponseException,
+)
 from .messages import (
-    HttpRequest,
-    HttpResponse,
+    RestRequest,
+    RestResponse,
 )
 
 logger = logging.getLogger(__name__)
@@ -53,17 +60,34 @@ class RestBuilder(MinosSetup):
 
     """
 
-    def __init__(self, host: str, port: int, endpoints: list[ENDPOINT], **kwargs):
+    def __init__(self, host: str, port: int, endpoints: dict[(str, str), Callable], **kwargs):
         super().__init__(**kwargs)
         self._host = host
         self._port = port
         self._endpoints = endpoints
 
+    @property
+    def endpoints(self) -> dict[(str, str), Callable]:
+        """Endpoints getter.
+
+        :return: A dictionary value.
+        """
+        return self._endpoints
+
     @classmethod
     def _from_config(cls, *args, config: MinosConfig, **kwargs) -> RestBuilder:
         host = config.rest.broker.host
         port = config.rest.broker.port
-        return cls(host=host, port=port, endpoints=config.rest.endpoints, **kwargs)
+
+        command_decorators = EnrouteBuilder(config.commands.service).get_rest_command_query()
+        query_decorators = EnrouteBuilder(config.queries.service).get_rest_command_query()
+
+        endpoints = {
+            (decorator.url, decorator.method): fn
+            for decorator, fn in chain(command_decorators.items(), query_decorators.items())
+        }
+
+        return cls(host=host, port=port, endpoints=endpoints, **kwargs)
 
     @property
     def host(self) -> str:
@@ -96,35 +120,19 @@ class RestBuilder(MinosSetup):
 
     def _mount_routes(self, app: web.Application):
         """Load routes from config file."""
-        for item in self._endpoints:
-            self._mount_one_route(item, app)
+        for (url, method), fn in self._endpoints.items():
+            self._mount_one_route(method, url, fn, app)
 
         # Load default routes
         self._mount_system_health(app)
 
-    def _mount_one_route(self, item: ENDPOINT, app: web.Application) -> NoReturn:
-        action = self.get_action(item.controller, item.action)
+    def _mount_one_route(self, method: str, url: str, action: Callable, app: web.Application) -> NoReturn:
         handler = self.get_callback(action)
-        app.router.add_route(item.method, item.route, handler)
-
-    @staticmethod
-    def get_action(
-        controller: str, action: str
-    ) -> Callable[[HttpRequest], Union[HttpResponse, Awaitable[HttpResponse]]]:
-        """Load controller class and action method.
-        :param controller: Controller string. Example: "tests.service.CommandTestService.CommandService"
-        :param action: Config instance. Example: "get_order"
-        :return: A class method callable instance.
-        """
-        controller = import_module(controller)
-        if isclass(controller):
-            controller = controller()
-        action_fn = getattr(controller, action)
-        return action_fn
+        app.router.add_route(method, url, handler)
 
     @staticmethod
     def get_callback(
-        fn: Callable[[HttpRequest], Union[HttpResponse, Awaitable[HttpResponse]]]
+        fn: Callable[[RestRequest], Union[Optional[RestResponse], Awaitable[Optional[RestResponse]]]]
     ) -> Callable[[web.Request], Awaitable[web.Response]]:
         """Get the handler function to be used by the ``aiohttp`` Controller.
 
@@ -134,12 +142,17 @@ class RestBuilder(MinosSetup):
 
         async def _fn(request: web.Request) -> web.Response:
             logger.info(f"Dispatching {classname(fn)!r} from {request.remote!r}...")
-            request = HttpRequest(request)
+            request = RestRequest(request)
 
             try:
                 response = fn(request)
                 if isawaitable(response):
                     response = await response
+                if isinstance(response, Response):
+                    response = await response.raw_content()
+                if response is None:
+                    return web.json_response()
+                return web.json_response(response)
             except ResponseException as exc:
                 logger.info(f"Raised a user exception: {exc!s}")
                 raise web.HTTPBadRequest(text=str(exc))
@@ -150,8 +163,6 @@ class RestBuilder(MinosSetup):
                 logger.exception(f"Raised an exception: {exc!r}.")
                 raise web.HTTPInternalServerError()
 
-            return web.json_response(await response.raw_content())
-
         return _fn
 
     def _mount_system_health(self, app: web.Application):
